#!/usr/bin/perl -w
# ======================================================================                                                                                                  
# SBDiffHTML - Unitex Sentence Boundary Diff Tool CSV results to HTML
# ====================================================================== 
# The script convert a SBDiffTool CSV file into HTML
# ======================================================================  
# GPL copyright 2011 by Cristian Martinez <martinec|at|esiee.fr>
# ======================================================================                                                                                                 
use strict; 
use warnings;
# ======================================================================
use Text::CSV;
use utf8;
use File::Basename;
use File::Spec;
use Readonly;
use Cwd 'abs_path';
# ======================================================================

# ======================================================================                 
# Constants 
# ======================================================================
#
Readonly my $CVS_HEADER 	=> "No,Start,End,Context,Tp,Context,No,Start,End\n";
Readonly my $VIEWER_PATH	=> "/viewer";

# ======================================================================                 
# Main program  
# ====================================================================== 
#
use open ':encoding(utf8)';
binmode(STDOUT, ":utf8");

my $sbdplain_fn	=  shift or die "Usage: $0 SBDDiff_file\n";

open my $sbdplain_fh, '<:encoding(utf8)', $sbdplain_fn 
	or die "Cannot open input file: $sbdplain_fn\n";


my $csv_in = Text::CSV->new ({
	binary => 1,always_quote => 1,}) 
	or die "Cannot use CSV: ".Text::CSV::Encoded->error_diag ();

my $csv_out = Text::CSV->new ({
	binary => 1,always_quote => 1,escape_char => "\\" }) 
	or die "Cannot use CSV: ".Text::CSV::Encoded->error_diag ();	

my $row = $csv_in->getline( $sbdplain_fh );
# ToDo: New Bug!
#($csv_in->string() eq $CVS_HEADER) or die "Invalid format SBDiff file: $sbdplain_fn\n";

my $viewerpath= dirname(File::Spec->rel2abs(__FILE__)).$VIEWER_PATH;

print <<EOM;
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" -->
<html>
<head>
<meta http-equiv="Content-type" content="text/html; charset=UTF-8" />
<title>SBDiffTool - Sentence Boundary Visual Diff Tool for Unitex</title>
<meta http-equiv="Content-Language" content="en-us" /> 

<style type="text/css" media="all">\@import "$viewerpath/css/style.css";</style>

<link rel="stylesheet" type="text/css" href="$viewerpath/grid/gt_grid.css" />
<link rel="stylesheet" type="text/css" href="$viewerpath/grid/skin/vista/skinstyle.css" />
<script type="text/javascript" src="$viewerpath/grid/gt_msg_en.js"></script>
<script type="text/javascript" src="$viewerpath/grid/gt_const.js"></script>
<script type="text/javascript" src="$viewerpath/grid/gt_grid_all.js"></script>
    
<script type="text/javascript" >
var grid_results = "myGrid" ;
var dsOption= {
	fields :[
		{name : 'KeySen' ,type: 'float' },
		{name : 'KSenStart' ,type: 'float' },
		{name : 'KSenEnd' ,type: 'float' },
		{name : 'KSenContext'  },
		{name : 'Type'  },
		{name : 'RSenContext'},
		{name : 'ResSen' ,type: 'float' },
		{name : 'RSenStart' ,type: 'float' },
		{name : 'ResSenEnd' ,type: 'float' }
		
	],

	recordType : 'array',
	data :
EOM

print "[\n";
while (($row = $csv_in->getline( $sbdplain_fh )) && defined $row && scalar(@$row)!=1) {
	if ($csv_out->combine (@$row)) {
	     my $string = $csv_out->string;
	     print "[$string],\n";
	}
	 else {
		 my $err = $csv_out->error_input;
	     print "combine () failed on argument: ", $err, "\n";
	}
	
}
print "]\n";

my $keyname	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $keysize	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $resname	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $ressize	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $count_crt	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $count_mis	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $count_fap	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $recall		= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $precision	= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
my $fscore		= ($row = $csv_in->getline( $sbdplain_fh )) ? $row->[1] : "";
	
print <<EOM;	
}

function my_renderer(value ,record,columnObj,grid,colNo,rowNo){
		var data= record[columnObj.fieldIndex];
		var color = data=='=='?"blue":(data=='+-'?"red":(data=='-+'?"#FAF200":"black"));
		return "<span style=\\"color:" + color +";\\"><strong>" + data + "</strong></span>";
}

var colsOption = [
	   {id: 'KeySen' , header: "No" , width : 55, align : "center"  },
	   {id: 'KSenStart' , header: "Start" , width :55, align : "center" },
	   {id: 'KSenEnd' , header: "End" , width :55, align : "center"  },
	   {id: 'KSenContext' , header: "Context" , width :280, toolTip : true ,toolTipWidth : 400, align : "left"},
	   {id: 'Type' , header: "Tp" , grouped : false, sortstate : 'asc',width :24, align : "center",renderer:my_renderer},
	   {id: 'RSenContext' , header: "Context" , width :280, toolTip : true ,toolTipWidth : 400, align : "left"},
	   {id: 'ResSen' , header: "No" , width :55, align : "center"},
	   {id: 'RSenStart' , header: "Start" , width :55, align : "center"},
	   {id: 'ResSenEnd' , header: "End" , width :55, align : "center"}
];

var gridOption={
	id : grid_results,
	width: "938",  //"100%", // 700,
	height: "350",  //"100%", // 330,
	
	container : 'gridbox', 
	replaceContainer : true, 
	
	customHead : 'myHead',

	dataset : dsOption ,
	columns : colsOption ,
	
	toolbarContent : 'nav | goto | print | filter',
	pageSize : 300,
	
	onMouseOver : function(value,  record,  cell,  row,  colNo, rowNo,  columnObj,  grid){
		if (columnObj && columnObj.toolTip) {
			grid.showCellToolTip(cell,columnObj.toolTipWidth);
		}else{
			grid.hideCellToolTip();
		}
	},
	onMouseOut : function(value,  record,  cell,  row,  colNo, rowNo,  columnObj,  grid){
		grid.hideCellToolTip();
	}
};

var mygrid=new Sigma.Grid( gridOption );
Sigma.Util.onLoad( Sigma.Grid.render(mygrid) );
</script>

</head>
<body>

<div id="page-container"> 
  <div id="header">
  <h1> SBDiffTool - Sentence Boundary Visual Diff Tool for Unitex </h1>
  </div>
  <div id="content">
	  <h2></h2>
      <div id="bigbox" style="margin:30px;display:!none;">
      <div id="gridbox" style="border:0px solid #cccccc;background-color:#f3f3f3;padding:5px;height:200px;width:700px;" ></div>
  </div>
      <h2>Results</h2>
      <hr align="left" noshade="noshade" size="1" class="bucketDivider">
      <p>
		<table align="center" border="0" cellpadding="6" cellspacing="0" style="width: 779px; height: 86px;">
			<tbody>
				<tr>
					<td style="background-color: rgb(102, 204, 204);">
						<strong>Correct</strong></td>
					<td style="background-color: rgb(102, 204, 204); text-align: center;">
						$count_crt</td>
					<td style="background-color: rgb(102, 204, 204); text-align: center;">
						<strong>==</strong></td>
					<th style="text-align: center; background-color: rgb(223, 223, 223);">
						<strong>Recall</strong></th>
					<th style="text-align: center; background-color: rgb(223, 223, 223);">
						<strong>Precision</strong></th>
					<th style="text-align: center; background-color: rgb(223, 223, 223);">
						<strong>Fscore</strong></th>
				</tr>
				<tr>
					<td style="background-color: rgb(255, 102, 102);">
						<strong>Missing</strong></td>
					<td style="background-color: rgb(255, 102, 102); text-align: center;">
						$count_mis</td>
					<td style="background-color: rgb(255, 102, 102); text-align: center;">
						<strong>+-</strong></td>
					<td colspan="1" rowspan="2" style="text-align: center;">
						<strong>$recall</strong><br />
						($count_crt/$keysize)</td>
					<td colspan="1" rowspan="2" style="text-align: center;">
						<strong>$precision</strong><br />
						($count_crt/$ressize)</td>
					<td colspan="1" rowspan="2" style="text-align: center;">
						<strong>$fscore</strong></td>
				</tr>
				<tr>
					<td style="background-color: rgb(255, 204, 51);">
						<strong>False positives</strong></td>
					<td style="background-color: rgb(255, 204, 51); text-align: center;">
						$count_fap</td>
					<td style="background-color: rgb(255, 204, 51); text-align: center;">
						<strong>-+</strong></td>
				</tr>
			</tbody>
		</table> 
      </p>
  </div>
  
</div>

<table id="myHead" style="display:left" border="1">
<tr align="center">
	<td colspan="4" >Reference ($keyname)</td>
	<td columnId='Type' rowspan="2" resizable='false'>⇄</td>
	<td colspan="4">Output ($resname)</td>
</tr>

<tr align="center">
	<td columnId='KeySen' resizable='false'>No</td>
	<td columnId='KSenStart' resizable='false'>Start</td>
	<td columnId='KSenEnd' resizable='false'>End</td>
	<td columnId='KSenContext'>Context</td>
	<td columnId='RSenContext'>Context</td>
	<td columnId='ResSen' resizable='false'>No</td>
	<td columnId='RSenStart' resizable='false'>Start</td>
	<td columnId='ResSenEnd' resizable='false'>End</td>
</tr>
</table>

</body>
</html>
EOM

				  
$csv_in->eof or $csv_in->error_diag();
$csv_out->eof or $csv_out->error_diag();
close $sbdplain_fh; 
