#!/bin/sh

if [ $# \< 2 ]
then echo "USAGE: $(basename $0) <key document> <response document> [<output file>]" 1>&2
     echo "		<key document> contains a Unitex (UTF-16LE) annotated reference sentence document file" 1>&2
     echo "		<response document> contains a Unitex (UTF-16LE) annotated response document file" 1>&2
     echo "		<output file> optional output csv file name" 1>&2
     exit 1
fi

if [ ! -s $1 ]; then
  "$1: key document doesn't exists or is empty" 1>&2
  exit 1  
fi

if [ ! -s $2 ]; then
  "$2: response document doesn't exists or is empty" 1>&2
  exit 1  
fi

TMPDIR=$(mktemp -d -t sbdiff-XXXXXX-plain)
trap "rm -rf $TMPDIR" EXIT

KEY_NAME=$(basename $1)
RES_NAME=$(basename $2)

INPUT_KEY=$TMPDIR/$KEY_NAME
INPUT_RES=$TMPDIR/$RES_NAME
(iconv -s -f UTF-16LE -t UTF-8 $1 -o $INPUT_KEY)  || { echo "Failed to convert key file to UTF-8"; exit 1; }
(iconv -s -f UTF-16LE -t UTF-8 $2 -o $INPUT_RES)  || { echo "Failed to convert key file to UTF-8"; exit 1; }

SCRIPT=$(readlink -f $0)
SCRIPTPATH=`dirname $SCRIPT`

if [ -z "$3" ]; then
	KEY_PART=${KEY_NAME%.*}
	RES_PART=${RES_NAME%.*}
	OUTPUT_PLAIN="$KEY_PART-$RES_PART.csv"
else
	OUTPUT_PLAIN=/dev/stdout
fi

$SCRIPTPATH/SBDiffPlain.pl $INPUT_KEY $INPUT_RES > $OUTPUT_PLAIN

rm -rf $TMPDIR
