#!/bin/sh
# ======================================================================                                                                                                  
# SBDDiffView - Unitex Sentence Boundary Diff Tool Viewer
# ====================================================================== 
# The script calculates recall, precision, and fscore value over all 
# sentences markers in unitex (UTF-16LE) tagged reference and response 
# files, and convert produced result into HTML file. The script call 
# SBDiffPlain.pl and SBDiffHTML.pl script files.
# ======================================================================  
# GPL copyright 2011 by Cristian Martinez <martinec|at|esiee.fr>
# ====================================================================== 

if [ $# \< 2 ]
then echo "USAGE: $(basename $0) <key document> <response document> [<output file>]" 1>&2
     echo "		<key document> contains an unitex (UTF-16LE) annotated key sentence document file" 1>&2
     echo "		<response document> contains an unitex (UTF-16LE) annotated response document file" 1>&2
     echo "		<output file> optional output html file name" 1>&2
     exit 1
fi

if [ ! -s $1 ]; then
  "$1: key document doesn't exists or is empty" 1>&2
  exit 1  
fi

if [ ! -s $2 ]; then
  "$2: response document doesn't exists or is empty" 1>&2
  exit 1  
fi

TMPDIR=$(mktemp -d -t sbdiff-XXXXXX-view)
trap "rm -rf $TMPDIR" EXIT

OUTPUT_PLAIN=$(mktemp -u $TMPDIR/XXXXXX.cvs) || { echo "Failed to create temp file"; exit 1; }
KEY_NAME=$(basename $1)
RES_NAME=$(basename $2)

INPUT_KEY=$TMPDIR/$KEY_NAME
INPUT_RES=$TMPDIR/$RES_NAME
(iconv -s -f UTF-16LE -t UTF-8 $1 -o $INPUT_KEY)  || { echo "Failed to convert key file to UTF-8"; exit 1; }
(iconv -s -f UTF-16LE -t UTF-8 $2 -o $INPUT_RES)  || { echo "Failed to convert key file to UTF-8"; exit 1; }

SCRIPT=$(readlink -f $0)
SCRIPTPATH=`dirname $SCRIPT`

if [ -z "$3" ]; then
	KEY_PART=${KEY_NAME%.*}
	RES_PART=${RES_NAME%.*}
	OUTPUT_HTML="$KEY_PART-$RES_PART.html"
else
	OUTPUT_HTML=$3
fi

echo "Comparing files..."
$SCRIPTPATH/SBDiffPlain.pl $INPUT_KEY $INPUT_RES > $OUTPUT_PLAIN
echo "Making html result..."
$SCRIPTPATH/SBDiffHTML.pl  $OUTPUT_PLAIN > $OUTPUT_HTML

rm -rf $TMPDIR

echo "Finished! Opening $OUTPUT_HTML"
path=$(which gnome-open || which xdg-open ) && exec "$path" "$OUTPUT_HTML" 2>/dev/null
echo "Can't find browser"
